@@ -17,4 +17,9 @@ filter.mRMR <-
 function (X, Y, nbreVarX_, ...) 
 {
     UseMethod("filter.mRMR")
+}
+filter.MAX <-
+function (nbreVarX_, ...) 
+{
+    UseMethod("filter.MAX")
 }
\ No newline at end of file
